const {
  watch,
  series,
  parallel,
  src,
  dest,
  lastRun
} = require('gulp');

// Plugins
const plumber = require('gulp-plumber'),
  rename = require('gulp-rename'),
  babel = require('gulp-babel'),
  uglify = require('gulp-uglify'),
  gulp_remove_logging = require("gulp-remove-logging"),
  sass = require('gulp-sass'),
  postcss = require('gulp-postcss'),
  cleanCss = require('gulp-clean-css'),
  autoprefixer = require('autoprefixer'),
  path = require('path'),
  notify = require('gulp-notify');

// Console colors (see: https://stackoverflow.com/questions/9781218/how-to-change-node-jss-console-font-color)
const successColor = "\x1b[32m",
  infoColor = "\x1b[36m",
  warningColor = "\x1b[33m",
  alertColor = "\x1b[33m";

// List the module ('./') and submodule directories here, its important to have the
// "js", "css" & "scss" folders as direct children of this folders.
var folders = [
  '.',
  'modules/drowl_media_video'
];

// Scripts Tasks
function buildScripts(done) {
  if (folders.length === 0) return done(); // nothing to do!
  var tasks = folders.map(function (folder) {
    return src([path.join(folder, '/js/**/*.js'), '!' + path.join(folder, '/js/**/*.min.js')], {
        since: lastRun(buildScripts)
      })
      .pipe(plumber())
      .pipe(rename({
        suffix: '.min'
      }))
      // Remove console logs
      .pipe(
        gulp_remove_logging()
      )
      // Transcompile ES6 code
      .pipe(babel({
        presets: ['@babel/env']
      }))
      // Minitfy / Uglify
      .pipe(
        uglify()
      )
      .pipe(notify({
        message: "Build Scripts: " + folder + "/ finished!",
        onLast: true
      }))
      .pipe(dest(folder + '/js'));
  });
  return [tasks, done()];
}

function buildSass(done) {
  if (folders.length === 0) return done(); // nothing to do!
  var tasks = folders.map(function (folder) {
    return src([path.join(folder, '/scss/**/*.scss')], {
        since: lastRun(buildSass)
      })
      .pipe(plumber())
      .pipe(sass.sync().on('error', sass.logError))
      .pipe(postcss([
        autoprefixer(),
        require('postcss-nested')
      ], {
        syntax: require('postcss-scss')
      }))
      // Minitfy / Uglify
      .pipe(rename({
        suffix: '.min'
      }))
      .pipe(
        cleanCss()
      )
      .pipe(notify({
        message: "SASS: " + folder + "/ finished!",
        onLast: true
      }))
      .pipe(dest(folder + '/css'));
  });
  return [tasks, done()];
};

exports.build = function (done) {
  // var doBuild = series(buildScripts, buildSass);
  var doBuild = series(buildScripts, buildSass);
  doBuild();
  done();
};
